@@ -68,7 +68,19 @@ NULL
       POSIXct_with_time_zone=rep(NA_character_, row.count),
       list_unnamed=as.list(rep(NA, row.count)),
       list_named=as.list(rep(NA, row.count)),
-      stop('Unsupported column type: ', type)
+      unknown=stop(
+        sprintf(paste0(
+          '"unknown" column type for column [%d], ',
+          'CAST() it to a known column type'
+        ), j)
+      ),
+      stop(
+        sprintf(paste0(
+          'Unsupported column type for column [%d], ',
+          'presto type: "%s", ',
+          'R type: "%s"'
+        ), j, names(column.types)[j], type)
+      )
     )
     if (type %in% 'POSIXct_with_time_zone') {
       attr(rv[[j]], 'tzone') <- 'UTC'
