@@ -71,7 +71,7 @@ test_that('db_query_fields works with mock', {
         request_body=paste0(
           '^SELECT \\* FROM \\(',
             '\\(SELECT 1 AS a, \'t\' AS b\\) "a"',
-          '\\) "zzz[0-9]+" LIMIT 0$'
+          '\\) "zzz[0-9]+" WHERE 1 = 0$'
         ),
         next_uri='http://localhost:8000/query_1/1'
       ),
@@ -89,7 +89,7 @@ test_that('db_query_fields works with mock', {
         # For dplyr 0.5.0
         request_body=paste0(
           '^SELECT \\* FROM "__non_existent_table__" ',
-          'AS "zzz[0-9]+" LIMIT 0$'
+          'AS "zzz[0-9]+" WHERE 1 = 0$'
         ),
         next_uri='http://localhost:8000/query_2/1',
       ),
@@ -105,7 +105,10 @@ test_that('db_query_fields works with mock', {
         status_code=200,
         state='FINISHED',
         # For dplyr 0.5.0
-        request_body='^SELECT \\* FROM "empty_table" AS "zzz[0-9]+" LIMIT 0$',
+        request_body=paste0(
+          '^SELECT \\* FROM "empty_table" AS "zzz[0-9]+"',
+          ' WHERE 1 = 0$'
+        ),
         next_uri='http://localhost:8000/query_3/1',
       ),
       mock_httr_response(
@@ -120,7 +123,10 @@ test_that('db_query_fields works with mock', {
         status_code=200,
         state='QUEUED',
         # For dplyr 0.5.0
-        request_body='^SELECT \\* FROM "two_columns" AS "zzz[0-9]+" LIMIT 0$',
+        request_body=paste0(
+          '^SELECT \\* FROM "two_columns" AS "zzz[0-9]+"',
+          ' WHERE 1 = 0$'
+        ),
         next_uri='http://localhost:8000/query_4/1',
       )
     ),
